from setuptools import setup, find_packages

setup(
    name="gps_transformer",
    version="1.0.0",
    packages=find_packages(),
    install_requires=[],  # Add dependencies here if needed
    entry_points={
        "console_scripts": [
            "Gps_Transformer=gps_transformer.main:main",  # Command-line usage
        ],
    },
    author="Your Name",
    author_email="your.email@example.com",
    description="A package to transform GPS coordinates in log files",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/projectest20/gps_transformer",  # Change this to your repo
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
